@@ -43,6 +43,7 @@ typedef struct _Ecore_Wl2_Seat Ecore_Wl2_Seat;
 typedef struct _Ecore_Wl2_Pointer Ecore_Wl2_Pointer;
 typedef struct _Ecore_Wl2_Keyboard Ecore_Wl2_Keyboard;
 typedef struct _Ecore_Wl2_Touch Ecore_Wl2_Touch;
+typedef struct _Ecore_Wl2_Offer Ecore_Wl2_Offer;
 
 /* matches protocol values */
 typedef enum
@@ -51,12 +52,22 @@ typedef enum
    ECORE_WL2_DRAG_ACTION_COPY = 1,
    ECORE_WL2_DRAG_ACTION_MOVE = 2,
    ECORE_WL2_DRAG_ACTION_ASK = 4,
+   ECORE_WL2_DRAG_ACTION_LAST = 5,
 } Ecore_Wl2_Drag_Action;
 
+typedef enum
+{
+  ECORE_WL2_SEAT_CAPABILITIES_NONE = 0,
+  ECORE_WL2_SEAT_CAPABILITIES_POINTER = 1,
+  ECORE_WL2_SEAT_CAPABILITIES_KEYBOARD = 2,
+  ECORE_WL2_SEAT_CAPABILITIES_TOUCH = 4
+} Ecore_Wl2_Seat_Capabilities;
+
 struct _Ecore_Wl2_Event_Connection
 {
    Ecore_Wl2_Display *display;
 };
+
 typedef struct _Ecore_Wl2_Event_Connection Ecore_Wl2_Event_Connect;
 typedef struct _Ecore_Wl2_Event_Connection Ecore_Wl2_Event_Disconnect;
 
@@ -64,6 +75,7 @@ typedef struct _Ecore_Wl2_Global
 {
    Eina_Stringshare *interface;
    unsigned int id, version;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Global;
 
 typedef struct _Ecore_Wl2_Event_Global
@@ -77,78 +89,141 @@ typedef struct _Ecore_Wl2_Event_Focus_In
 {
    unsigned int window;
    unsigned int timestamp;
+   Eo *dev; //The seat device
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Focus_In;
 
 typedef struct _Ecore_Wl2_Event_Focus_Out
 {
    unsigned int window;
    unsigned int timestamp;
+   Eo *dev; //The seat device
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Focus_Out;
 
 typedef struct _Ecore_Wl2_Event_Dnd_Enter
 {
-   unsigned int win, source, serial;
-   char **types;
-   int num_types, x, y;
-   struct wl_data_offer *offer;
+   unsigned int win, source;
+   Ecore_Wl2_Offer *offer;
+   int x, y;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Dnd_Enter;
 
 typedef struct _Ecore_Wl2_Event_Dnd_Leave
 {
    unsigned int win, source;
+   Ecore_Wl2_Offer *offer;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Dnd_Leave;
 
 typedef struct _Ecore_Wl2_Event_Dnd_Motion
 {
-   unsigned int win, source, serial;
+   unsigned int win, source;
+   Ecore_Wl2_Offer *offer;
    int x, y;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Dnd_Motion;
 
 typedef struct _Ecore_Wl2_Event_Dnd_Drop
 {
    unsigned int win, source;
    int x, y;
+   Ecore_Wl2_Offer *offer;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Dnd_Drop;
 
 typedef struct _Ecore_Wl2_Event_Dnd_End
 {
    unsigned int win, source;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Dnd_End;
 
 struct _Ecore_Wl2_Event_Data_Source_Event
 {
    unsigned int win, source;
    Ecore_Wl2_Drag_Action action;
+   unsigned int seat;
+   uint32_t serial;
+   Ecore_Wl2_Display *display;
 };
 
-typedef struct _Ecore_Wl2_Event_Data_Source_Event Ecore_Wl2_Event_Data_Source_End;
+typedef struct Ecore_Wl2_Event_Data_Source_End
+{
+   unsigned int win, source;
+   Ecore_Wl2_Drag_Action action;
+   unsigned int seat;
+   uint32_t serial;
+   Ecore_Wl2_Display *display;
+   Eina_Bool cancelled;
+} Ecore_Wl2_Event_Data_Source_End;
 typedef struct _Ecore_Wl2_Event_Data_Source_Event Ecore_Wl2_Event_Data_Source_Drop;
 typedef struct _Ecore_Wl2_Event_Data_Source_Event Ecore_Wl2_Event_Data_Source_Action;
 
 typedef struct _Ecore_Wl2_Event_Data_Source_Target
 {
    char *type;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Data_Source_Target;
 
 typedef struct _Ecore_Wl2_Event_Data_Source_Send
 {
    char *type;
    int fd;
+   unsigned int seat;
+   uint32_t serial;
+   Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Data_Source_Send;
 
+typedef struct Ecore_Wl2_Event_Seat_Selection
+{
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Seat_Selection;
+
+typedef struct _Ecore_Wl2_Event_Seat_Name
+{
+   Eina_Stringshare *name;
+   unsigned int id;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Seat_Name;
+
+typedef struct _Ecore_Wl2_Event_Seat_Capabilities
+{
+   unsigned int id;
+   Eina_Bool pointer_enabled : 1;
+   Eina_Bool keyboard_enabled : 1;
+   Eina_Bool touch_enabled : 1;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Seat_Capabilities;
+
+typedef enum
+{
+   ECORE_WL2_DEVICE_TYPE_SEAT,
+   ECORE_WL2_DEVICE_TYPE_POINTER,
+   ECORE_WL2_DEVICE_TYPE_KEYBOARD,
+   ECORE_WL2_DEVICE_TYPE_TOUCH
+} Ecore_Wl2_Device_Type;
+
+typedef struct _Ecore_Wl2_Event_Device
+{
+   Eo *dev;
+   int window_id;
+   unsigned int seat_id;
+   Ecore_Wl2_Device_Type type;
+} Ecore_Wl2_Event_Device;
+
 typedef enum
 {
    ECORE_WL2_SELECTION_CNP,
    ECORE_WL2_SELECTION_DND
 } Ecore_Wl2_Selection_Type;
 
-typedef struct _Ecore_Wl2_Event_Selection_Data_Ready
-{
-   char *data;
-   int len;
-   Ecore_Wl2_Selection_Type sel_type;
-} Ecore_Wl2_Event_Selection_Data_Ready;
-
 typedef enum
 {
    ECORE_WL2_WINDOW_STATE_NONE = 0,
@@ -163,11 +238,83 @@ typedef struct _Ecore_Wl2_Event_Window_Configure
    unsigned int states;
 } Ecore_Wl2_Event_Window_Configure;
 
+typedef struct _Ecore_Wl2_Event_Window_Configure_Complete
+{
+   unsigned int win;
+} Ecore_Wl2_Event_Window_Configure_Complete;
+
+typedef struct _Ecore_Wl2_Event_Input_Keymap_Changed
+{
+   unsigned int id;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Seat_Keymap_Changed;
+
+typedef struct Ecore_Wl2_Event_Seat_Keyboard_Repeat_Changed
+{
+   unsigned int id;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Seat_Keyboard_Repeat_Changed;
+
 typedef struct _Ecore_Wl2_Event_Sync_Done
 {
    Ecore_Wl2_Display *display;
 } Ecore_Wl2_Event_Sync_Done;
 
+typedef struct _Ecore_Wl2_Event_Offer_Data_Ready
+{
+   Ecore_Wl2_Offer *offer;
+   char *data;
+   int len;
+   const char *mimetype;
+   unsigned int seat;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Offer_Data_Ready;
+
+typedef struct _Ecore_Wl2_Event_Output_Transform
+{
+   Ecore_Wl2_Output *output;
+   int transform, old_transform;
+} Ecore_Wl2_Event_Output_Transform;
+
+typedef struct _Ecore_Wl2_Event_Window_Rotation
+{
+   unsigned int win;
+   int rotation, w, h, angle;
+   Eina_Bool resize : 1;
+} Ecore_Wl2_Event_Window_Rotation;
+typedef struct _Ecore_Wl2_Event_Window_Rotation Ecore_Wl2_Event_Window_Rotation_Change_Prepare;
+typedef struct _Ecore_Wl2_Event_Window_Rotation Ecore_Wl2_Event_Window_Rotation_Change_Prepare_Done;
+typedef struct _Ecore_Wl2_Event_Window_Rotation Ecore_Wl2_Event_Window_Rotation_Change_Request;
+typedef struct _Ecore_Wl2_Event_Window_Rotation Ecore_Wl2_Event_Window_Rotation_Change_Done;
+
+typedef struct _Ecore_Wl2_Event_Window_Show
+{
+   unsigned int win;
+   unsigned int parent_win;
+   unsigned int event_win;
+} Ecore_Wl2_Event_Window_Show;
+
+typedef struct _Ecore_Wl2_Event_Window_Hide
+{
+   unsigned int win;
+   unsigned int parent_win;
+   unsigned int event_win;
+} Ecore_Wl2_Event_Window_Hide;
+
+typedef struct _Ecore_Wl2_Event_Window_Activate
+{
+   unsigned int win;
+   unsigned int parent_win;
+   unsigned int event_win;
+} Ecore_Wl2_Event_Window_Activate;
+
+typedef struct _Ecore_Wl2_Event_Window_Deactivate
+{
+   unsigned int win;
+   unsigned int parent_win;
+   unsigned int event_win;
+} Ecore_Wl2_Event_Window_Deactivate;
+
 typedef enum _Ecore_Wl2_Window_Type
 {
    ECORE_WL2_WINDOW_TYPE_NONE,
@@ -175,9 +322,36 @@ typedef enum _Ecore_Wl2_Window_Type
    ECORE_WL2_WINDOW_TYPE_MENU,
    ECORE_WL2_WINDOW_TYPE_DND,
    ECORE_WL2_WINDOW_TYPE_CUSTOM,
+   ECORE_WL2_WINDOW_TYPE_NOTIFICATION, /** @since 1.20 */
+   ECORE_WL2_WINDOW_TYPE_UTILITY, /** @since 1.20 */
+   ECORE_WL2_WINDOW_TYPE_DIALOG, /** @since 1.20 */
+   ECORE_WL2_WINDOW_TYPE_DOCK, /** @since 1.20 */
+   ECORE_WL2_WINDOW_TYPE_SPLASH, /** @since 1.20 */
    ECORE_WL2_WINDOW_TYPE_LAST
 } Ecore_Wl2_Window_Type;
 
+typedef struct _Ecore_Wl2_Event_Aux_Hint_Allowed
+{
+   unsigned int win;
+   int id;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Aux_Hint_Allowed;
+
+typedef struct _Ecore_Wl2_Event_Aux_Hint_Supported
+{
+   unsigned int win;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Aux_Hint_Supported;
+
+typedef struct Ecore_Wl2_Event_Aux_Message
+{
+   unsigned int win;
+   Eina_Stringshare *key;
+   Eina_Stringshare *val;
+   Eina_List *options;
+   Ecore_Wl2_Display *display;
+} Ecore_Wl2_Event_Aux_Message;
+
 typedef void (*Ecore_Wl2_Bind_Cb)(struct wl_client *client, void *data, uint32_t version, uint32_t id);
 typedef void (*Ecore_Wl2_Unbind_Cb)(struct wl_resource *resource);
 
@@ -192,15 +366,35 @@ EAPI extern int ECORE_WL2_EVENT_DND_LEAVE; /** @since 1.17 */
 EAPI extern int ECORE_WL2_EVENT_DND_MOTION; /** @since 1.17 */
 EAPI extern int ECORE_WL2_EVENT_DND_DROP; /** @since 1.17 */
 EAPI extern int ECORE_WL2_EVENT_DND_END; /** @since 1.17 */
-EAPI extern int ECORE_WL2_EVENT_DND_DATA_READY; /** @since 1.18 */
 EAPI extern int ECORE_WL2_EVENT_DATA_SOURCE_END; /** @since 1.18 */
 EAPI extern int ECORE_WL2_EVENT_DATA_SOURCE_DROP; /** @since 1.18 */
 EAPI extern int ECORE_WL2_EVENT_DATA_SOURCE_ACTION; /** @since 1.18 */
 EAPI extern int ECORE_WL2_EVENT_DATA_SOURCE_TARGET; /** @since 1.17 */
 EAPI extern int ECORE_WL2_EVENT_DATA_SOURCE_SEND; /** @since 1.17 */
-EAPI extern int ECORE_WL2_EVENT_CNP_DATA_READY; /** @since 1.18 */
 EAPI extern int ECORE_WL2_EVENT_WINDOW_CONFIGURE; /** @since 1.17 */
 EAPI extern int ECORE_WL2_EVENT_SYNC_DONE; /** @since 1.17 */
+EAPI extern int ECORE_WL2_EVENT_OFFER_DATA_READY; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_SEAT_NAME_CHANGED; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_SEAT_CAPABILITIES_CHANGED; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_DEVICE_ADDED; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_DEVICE_REMOVED; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_CONFIGURE_COMPLETE; /** @since 1.19 */
+EAPI extern int ECORE_WL2_EVENT_SEAT_KEYMAP_CHANGED; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_SEAT_KEYBOARD_REPEAT_CHANGED; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_SEAT_SELECTION; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_OUTPUT_TRANSFORM; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ROTATE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ROTATION_CHANGE_PREPARE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ROTATION_CHANGE_PREPARE_DONE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ROTATION_CHANGE_REQUEST; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ROTATION_CHANGE_DONE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_AUX_HINT_ALLOWED; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_AUX_HINT_SUPPORTED; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_AUX_MESSAGE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_SHOW; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_HIDE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_ACTIVATE; /** @since 1.20 */
+EAPI extern int ECORE_WL2_EVENT_WINDOW_DEACTIVATE; /** @since 1.20 */
 
 /**
  * @file
@@ -404,6 +598,35 @@ EAPI Eina_Iterator *ecore_wl2_display_globals_get(Ecore_Wl2_Display *display);
  */
 EAPI void ecore_wl2_display_screen_size_get(Ecore_Wl2_Display *display, int *w, int *h);
 
+/**
+ * Get all the Ecore_Wl2_Input from the display.
+ * @param display The display
+ * @return A Eina_Iterator of Ecore_Wl2_Input or @c NULL on error
+ * @ingroup Ecore_Wl2_Display_Group
+ * @since 1.19
+ */
+EAPI Eina_Iterator *ecore_wl2_display_inputs_get(Ecore_Wl2_Display *display);
+
+/**
+ * Find a seat for a given display object using the seat id
+ * @param display The display
+ * @param id The seat id
+ * @return The corresponding Ecore_Wl2_Input object or @c NULL if no match is found
+ * @ingroup Ecore_Wl2_Display_Group
+ * @since 1.20
+ */
+EAPI Ecore_Wl2_Input *ecore_wl2_display_input_find(const Ecore_Wl2_Display *display, unsigned int id);
+
+/**
+ * Find a seat for a given display object using the seat id
+ * @param display The display
+ * @param name The seat name
+ * @return The corresponding Ecore_Wl2_Input object or @c NULL if no match is found
+ * @ingroup Ecore_Wl2_Display_Group
+ * @since 1.20
+ */
+EAPI Ecore_Wl2_Input *ecore_wl2_display_input_find_by_name(const Ecore_Wl2_Display *display, const char *name);
+
 /**
  * Find an Ecore_Wl2_Window based on id
  *
@@ -429,6 +652,31 @@ EAPI Ecore_Wl2_Window *ecore_wl2_display_window_find(Ecore_Wl2_Display *display,
  */
 EAPI struct wl_registry *ecore_wl2_display_registry_get(Ecore_Wl2_Display *display);
 
+/**
+ * Check if the display has performed a sync
+ *
+ * @param display The display
+ *
+ * @return True if the display sync has occurred
+ * @see ECORE_WL2_EVENT_SYNC_DONE
+ *
+ * @ingroup Ecore_Wl2_Display_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_display_sync_is_done(const Ecore_Wl2_Display *display);
+
+/**
+ * Get the name of the display object
+ *
+ * @param display The display
+ *
+ * @return The name of the display object
+ *
+ * @ingroup Ecore_Wl2_Display_Group
+ * @since 1.20
+ */
+EAPI const char *ecore_wl2_display_name_get(const Ecore_Wl2_Display *display);
+
 /**
  * @defgroup Ecore_Wl2_Window_Group Wayland Library Window Functions
  * @ingroup Ecore_Wl2_Group
@@ -519,35 +767,27 @@ EAPI void ecore_wl2_window_hide(Ecore_Wl2_Window *window);
 EAPI void ecore_wl2_window_free(Ecore_Wl2_Window *window);
 
 /**
- * Move a given Ecore_Wl2_Window
- *
- * @brief The position requested (@p x, @p y) is not honored by Wayland because
- * Wayland does not allow specific window placement to be set.
+ * @brief Begin moving a given Ecore_Wl2_Window
  *
  * @param window The Ecore_Wl2_Window which to move
- * @param x Desired x position of window
- * @param y Desired y position of window
+ * @param input The seat on which the move is active on
  *
  * @ingroup Ecore_Wl2_Window_Group
- * @since 1.17
+ * @since 1.20
  */
-EAPI void ecore_wl2_window_move(Ecore_Wl2_Window *window, int x, int y);
+EAPI void ecore_wl2_window_move(Ecore_Wl2_Window *window, Ecore_Wl2_Input *input);
 
 /**
- * Resize a given Ecore_Wl2_Window
- *
- * @brief The size requested (@p w, @p h) is not honored by Wayland because
- * Wayland does not allow specific window sizes to be set.
+ * @brief Begin resizing a given window
  *
  * @param window The Ecore_Wl2_Window which to resize
- * @param w Desired width of window
- * @param h Desired height of window
- * @param location The edge of the window from where the resize should start
+ * @param input The seat on which the resize is active
+ * @param location The edge of the window from which the resize should start
  *
  * @ingroup Ecore_Wl2_Window_Group
- * @since 1.17
+ * @since 1.20
  */
-EAPI void ecore_wl2_window_resize(Ecore_Wl2_Window *window, int w, int h, int location);
+EAPI void ecore_wl2_window_resize(Ecore_Wl2_Window *window, Ecore_Wl2_Input *input, int location);
 
 /**
  * Raise a given Ecore_Wl2_Window
@@ -776,46 +1016,6 @@ EAPI Eina_Bool ecore_wl2_window_iconified_get(Ecore_Wl2_Window *window);
  */
 EAPI void ecore_wl2_window_iconified_set(Ecore_Wl2_Window *window, Eina_Bool iconified);
 
-/**
- * Retrieves the mouse position of the current window.
- *
- * @param window The window on which to retrieve the mouse position
- * @param x where to return the horizontal position. May be NULL. Returns 0 on error.
- * @param y where to return the vertical position. May be NULL. Returns 0 on error.
- *
- * @ingroup Ecore_Wl2_Window_Group
- * @since 1.17
- */
-EAPI void ecore_wl2_window_pointer_xy_get(Ecore_Wl2_Window *window, int *x, int *y);
-
-/**
- * Set a given wl_surface to use as the pointer on a window
- *
- * @param window The window to set this surface as the pointer on
- * @param surface The surface to use as the pointer
- * @param hot_x The x coordinate to use as the cursor hot spot
- * @param hot_y The y coordinate to use as the cursor hot spot
- *
- * @ingroup Ecore_Wl2_Window_Group
- * @since 1.17
- */
-EAPI void ecore_wl2_window_pointer_set(Ecore_Wl2_Window *window, struct wl_surface *surface, int hot_x, int hot_y);
-
-/**
- * Set a specific cursor on a given window
- *
- * @brief This function will try to find a matching cursor inside the existing
- * cursor theme and set the pointer which is over the given window to be
- * the specified cursor
- *
- * @param window The window to set the cursor on
- * @param cursor The name of the cursor to try and set
- *
- * @ingroup Ecore_Wl2_Window_Group
- * @since 1.17
- */
-EAPI void ecore_wl2_window_cursor_from_name_set(Ecore_Wl2_Window *window, const char *cursor);
-
 /**
  * Set the type of a given window
  *
@@ -827,9 +1027,271 @@ EAPI void ecore_wl2_window_cursor_from_name_set(Ecore_Wl2_Window *window, const
  */
 EAPI void ecore_wl2_window_type_set(Ecore_Wl2_Window *window, Ecore_Wl2_Window_Type type);
 
-/* TODO: doxy */
+/**
+ * Find the output that a given window is on
+ *
+ * @param window The window to find the output for
+ *
+ * @return An Ecore_Wl2_Output if found, or NULL otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Ecore_Wl2_Output *ecore_wl2_window_output_find(Ecore_Wl2_Window *window);
+
+/**
+ * Set a buffer transform on a given window
+ *
+ * @param window The window on which to set the buffer transform
+ * @param transform The buffer transform being requested
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_buffer_transform_set(Ecore_Wl2_Window *window, int transform);
+
+/**
+ * Set if window rotation is supported by the window manager
+ *
+ * @param window
+ * @param enabled
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_wm_rotation_supported_set(Ecore_Wl2_Window *window, Eina_Bool enabled);
+
+/**
+ * Get if window rotation is supported by the window manager
+ *
+ * @param window
+ *
+ * @return EINA_TRUE if supported, EINA_FALSE otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_wm_rotation_supported_get(Ecore_Wl2_Window *window);
+
+/**
+ * Set if an application has set window rotation
+ *
+ * @param window
+ * @param set
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_rotation_app_set(Ecore_Wl2_Window *window, Eina_Bool set);
+
+/**
+ * Get if an application has set window rotation
+ *
+ * @param window
+ *
+ * @return EINA_TRUE if set, EINA_FALSE otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_rotation_app_get(Ecore_Wl2_Window *window);
+
+/**
+ * Set preferred rotation on a given window
+ *
+ * @param window
+ * @param rot
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_preferred_rotation_set(Ecore_Wl2_Window *window, int rot);
+
+/**
+ * Get preferred rotation for a given window
+ *
+ * @param window
+ *
+ * @return Given windows preferred rotation
+ *
+ * @ingroup Ecore_Wl2_Window
+ * @since 1.20
+ */
+EAPI int ecore_wl2_window_preferred_rotation_get(Ecore_Wl2_Window *window);
+
+/**
+ * Set a windows available rotations
+ *
+ * @param window
+ * @param rots
+ * @param count
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_available_rotations_set(Ecore_Wl2_Window *window, const int *rots, unsigned int count);
+
+/**
+ * Get a windows available rotations
+ *
+ * @param window
+ * @param rots
+ * @param count
+ *
+ * @return EINA_TRUE on success, EINA_FALSE otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_available_rotations_get(Ecore_Wl2_Window *window, int **rots, unsigned int *count);
+
+EAPI void ecore_wl2_window_rotation_change_prepare_send(Ecore_Wl2_Window *window, int rot, int w, int h, Eina_Bool resize);
+EAPI void ecore_wl2_window_rotation_change_prepare_done_send(Ecore_Wl2_Window *window, int rot);
+EAPI void ecore_wl2_window_rotation_change_request_send(Ecore_Wl2_Window *window, int rot);
+EAPI void ecore_wl2_window_rotation_change_done_send(Ecore_Wl2_Window *window, int rot, int w, int h);
+
+/**
+ * Get list of supported auxiliary window hints
+ *
+ * @param window
+ *
+ * @return An Eina_List of supported auxiliary hints, or NULL otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_List *ecore_wl2_window_aux_hints_supported_get(Ecore_Wl2_Window *window);
+
+/**
+ * Add a supported auxiliary hint to a given window
+ *
+ * @param window
+ * @param id
+ * @param hint
+ * @param val
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_aux_hint_add(Ecore_Wl2_Window *window, int id, const char *hint, const char *val);
+
+/**
+ * Change an auxiliary hint on a given window
+ *
+ * @param window
+ * @param id
+ * @param val
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_aux_hint_change(Ecore_Wl2_Window *window, int id, const char *val);
+
+/**
+ * Delete an auxiliary hint on a given window
+ *
+ * @param window
+ * @param id
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_aux_hint_del(Ecore_Wl2_Window *window, int id);
+
+/**
+ * @brief Get the activated state of a window
+ * @param window The window
+ * @return @c EINA_TRUE if activated
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_activated_get(const Ecore_Wl2_Window *window);
+
+/**
+ * @brief Set the seat for a popup window to be used with grab
+ * @param window The window
+ * @param input The seat
+ *
+ * Use this function for desktop shell requests involving popup grabs which require
+ * a seat for the grab.
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_popup_input_set(Ecore_Wl2_Window *window, Ecore_Wl2_Input *input);
+
+/**
+ * Check if a window has a shell surface - without one it can't be visible.
+ *
+ * @param The window to check
+ *
+ * @return Returns true if the window has an associated shell surface.
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.19
+ */
+EAPI Eina_Bool ecore_wl2_window_shell_surface_exists(Ecore_Wl2_Window *win);
+
 /** @since 1.17 */
-EAPI Ecore_Wl2_Input *ecore_wl2_window_input_get(Ecore_Wl2_Window *window);
+EAPI Ecore_Wl2_Display *ecore_wl2_window_display_get(const Ecore_Wl2_Window *window);
+
+/**
+ * Set if this window should ignore focus requests
+ *
+ * @param window
+ * @param focus_skip
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_focus_skip_set(Ecore_Wl2_Window *window, Eina_Bool focus_skip);
+
+/**
+ * Get if this window ignores focus requests
+ *
+ * @param window
+ *
+ * @return EINA_TRUE if a window should skip focus requests, EINA_FALSE otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_focus_skip_get(Ecore_Wl2_Window *window);
+
+/**
+ * Set the role of a given window
+ *
+ * @param window
+ * @param role
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_role_set(Ecore_Wl2_Window *window, const char *role);
+
+/**
+ * Set if a given window is in floating mode
+ *
+ * @param window
+ * @param floating
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_window_floating_mode_set(Ecore_Wl2_Window *window, Eina_Bool floating);
+
+/**
+ * Get if a given window is in floating mode
+ *
+ * @param window
+ *
+ * @return EINA_TRUE if floating, EINA_FALSE otherwise
+ *
+ * @ingroup Ecore_Wl2_Window_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_window_floating_mode_get(Ecore_Wl2_Window *window);
 
 /**
  * @defgroup Ecore_Wl2_Input_Group Wayland Library Input Functions
@@ -851,6 +1313,114 @@ EAPI void ecore_wl2_input_ungrab(Ecore_Wl2_Input *input);
 /** @since 1.17 */
 EAPI struct wl_seat *ecore_wl2_input_seat_get(Ecore_Wl2_Input *input);
 
+/**
+ * Get the seat capabilities for a given input.
+ *
+ * @param input The input
+ *
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.19
+ */
+EAPI Ecore_Wl2_Seat_Capabilities ecore_wl2_input_seat_capabilities_get(Ecore_Wl2_Input *input);
+
+/**
+ * Get the wayland's seat id from an input.
+ * @param input The input
+ * @return The seat id
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.19
+ */
+EAPI unsigned int ecore_wl2_input_seat_id_get(Ecore_Wl2_Input *input);
+
+/**
+ * Get the display object of an input
+ * @param input The input
+ * @return The display
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI Ecore_Wl2_Display *ecore_wl2_input_display_get(const Ecore_Wl2_Input *input);
+
+/**
+ * Get the xkb_keymap object of an input
+ * @param input The input
+ * @return The xkb_keymap object
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI struct xkb_keymap *ecore_wl2_input_keymap_get(const Ecore_Wl2_Input *input);
+
+/**
+ * Get the name of an input
+ * @param input The input
+ * @return The name
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI Eina_Stringshare *ecore_wl2_input_name_get(Ecore_Wl2_Input *input);
+
+/**
+ * Get the keyboard repeat rate and delay of an input
+ * @param input The input
+ * @param rate Pointer to store the repeat rate (in seconds)
+ * @param rate Pointer to store the repeat delay (in seconds)
+ * @return True if repeat is enabled
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_input_keyboard_repeat_get(const Ecore_Wl2_Input *input, double *rate, double *delay);
+
+/**
+ * Get the Evas_Device for the seat belonging to a window from an input
+ * @param input The input
+ * @param window The window
+ * @return The device object
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI Eo *ecore_wl2_input_seat_device_get(const Ecore_Wl2_Input *input, const Ecore_Wl2_Window *window);
+
+/**
+ * Retrieves the mouse position of the seat
+ *
+ * @param input The seat
+ * @param x where to return the horizontal position. May be NULL. Returns 0 on error.
+ * @param y where to return the vertical position. May be NULL. Returns 0 on error.
+ * @return @c EINA_TRUE if coords were successfully retrieved
+ *
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_wl2_input_pointer_xy_get(const Ecore_Wl2_Input *input, int *x, int *y);
+
+/**
+ * Set a given wl_surface to use as the pointer on a seat
+ *
+ * @param input The seat to set this surface as the pointer on
+ * @param surface The surface to use as the pointer
+ * @param hot_x The x coordinate to use as the cursor hot spot
+ * @param hot_y The y coordinate to use as the cursor hot spot
+ *
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_input_pointer_set(Ecore_Wl2_Input *input, struct wl_surface *surface, int hot_x, int hot_y);
+
+/**
+ * Set a specific cursor on a given seat
+ *
+ * @brief This function will try to find a matching cursor inside the existing
+ * cursor theme and set the pointer for the specified seat to be
+ * the specified cursor
+ *
+ * @param input The seat to set the cursor on
+ * @param cursor The name of the cursor to try and set
+ *
+ * @ingroup Ecore_Wl2_Input_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_input_cursor_from_name_set(Ecore_Wl2_Input *input, const char *cursor);
+
 /**
  * @defgroup Ecore_Wl2_Dnd_Group Wayland Library Drag-n-Drop Functions
  * @ingroup Ecore_Wl2_Group
@@ -859,37 +1429,93 @@ EAPI struct wl_seat *ecore_wl2_input_seat_get(Ecore_Wl2_Input *input);
  * Wayland Drag-n-Drop
  */
 
-/* TODO: doxy */
-/** @since 1.17 */
+/**
+ * Set the types which are supported by a possible drag and drop operation.
+ * This call initializes a data source and offeres the given mimetypes
+ *
+ * @param input the input where to add on the data source
+ *
+ * @param types a null-terminated array of mimetypes
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.17
+ */
 EAPI void ecore_wl2_dnd_drag_types_set(Ecore_Wl2_Input *input, const char **types);
 
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI void ecore_wl2_dnd_drag_start(Ecore_Wl2_Input *input, Ecore_Wl2_Window *window, Ecore_Wl2_Window *drag_window);
+/**
+ * Start a drag on the given input
+ *
+ * @param input the input to use
+ *
+ * @param window the window which is the origin of the drag operation
+ *
+ * @param drag_window the window which is used as window of the visible hint.
+ * @return The serial for the start_drag request
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.17
+ */
+EAPI uint32_t ecore_wl2_dnd_drag_start(Ecore_Wl2_Input *input, Ecore_Wl2_Window *window, Ecore_Wl2_Window *drag_window);
 
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_dnd_drag_get(Ecore_Wl2_Input *input, const char *type);
+/**
+ * Call wl_data_source.set_actions on an existing source
+ *
+ * @param input the input to use
+ *
+ * @see ecore_wl2_dnd_drag_start for a more useful function.
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.20
+ */
+EAPI EAPI void ecore_wl2_dnd_set_actions(Ecore_Wl2_Input *input);
 
-/* TODO: doxy */
-/** @since 1.17 */
+/**
+ * End a drag started by a call to ecore_wl2_dnd_drag_start
+ *
+ * @param input the input object on which the drag was started
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.17
+ */
 EAPI void ecore_wl2_dnd_drag_end(Ecore_Wl2_Input *input);
 
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_dnd_selection_owner_has(Ecore_Wl2_Input *input);
+/**
+ * Get the offer which is currently resposible for the clipboard
+ *
+ * @param input the input object to use
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI Ecore_Wl2_Offer* ecore_wl2_dnd_selection_get(Ecore_Wl2_Input *input);
 
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_dnd_selection_set(Ecore_Wl2_Input *input, const char **types);
+/**
+ * Set the types which are available from this client
+ * Later the event ECORE_WL2_EVENT_DATA_SOURCE_SEND is emitted,
+ * where the caller of this api must write the data (encoded in the given mimetype) to the fd
+ *
+ * @param input the input to provice this types on
+ *
+ * @param types a null-terminated array of mimetypes supported by the client
+ *
+ * @return serial of request on sucess, 0 on failure
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.17
+ */
+EAPI uint32_t ecore_wl2_dnd_selection_set(Ecore_Wl2_Input *input, const char **types);
 
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_dnd_selection_get(Ecore_Wl2_Input *input, const char *type);
-
-/* TODO: doxy */
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_dnd_selection_clear(Ecore_Wl2_Input *input);
+/**
+ * Clear the selection currently setted on this input.
+ *
+ * @param input the input to clear
+ *
+ * @return serial of request on sucess, 0 on failure
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.17
+ */
+EAPI uint32_t ecore_wl2_dnd_selection_clear(Ecore_Wl2_Input *input);
 
 /**
  * @defgroup Ecore_Wl2_Subsurface_Group Functions to manipulate subsurfaces.
@@ -1072,6 +1698,17 @@ EAPI void ecore_wl2_subsurface_opaque_region_set(Ecore_Wl2_Subsurface *subsurfac
  */
 EAPI int ecore_wl2_output_dpi_get(Ecore_Wl2_Output *output);
 
+/**
+ * Get the current transform of a given output
+ *
+ * @param output The output to get the transform of
+ *
+ * @return The output's current transform value
+ * @ingroup Ecore_Wl2_Output_Group
+ * @since 1.20
+ */
+EAPI int ecore_wl2_output_transform_get(Ecore_Wl2_Output *output);
+
 /**
  * Return the version of the display's compositor object
  *
@@ -1084,37 +1721,150 @@ EAPI int ecore_wl2_output_dpi_get(Ecore_Wl2_Output *output);
  */
 EAPI int ecore_wl2_display_compositor_version_get(Ecore_Wl2_Display *disp);
 
-/** @since 1.17 */
-EAPI Ecore_Wl2_Seat *ecore_wl2_seat_create(Ecore_Wl2_Display *display, const char *name, const struct wl_seat_interface *implementation, int version, Ecore_Wl2_Bind_Cb bind_cb, Ecore_Wl2_Unbind_Cb unbind_cb);
-/** @since 1.17 */
-EAPI void ecore_wl2_seat_destroy(Ecore_Wl2_Seat *seat);
-/** @since 1.17 */
-EAPI void ecore_wl2_seat_capabilities_send(Ecore_Wl2_Seat *seat, enum wl_seat_capability caps);
-/** @since 1.17 */
-EAPI void ecore_wl2_seat_pointer_release(Ecore_Wl2_Seat *seat);
+/**
+ * Get the actions available from the data source
+ *
+ * @param offer Offer object to use
+ *
+ * @return or´ed values from Ecore_Wl2_Drag_Action which are describing the available actions
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI Ecore_Wl2_Drag_Action ecore_wl2_offer_actions_get(Ecore_Wl2_Offer *offer);
 
-/** @since 1.17 */
-EAPI Ecore_Wl2_Pointer *ecore_wl2_pointer_get(Ecore_Wl2_Seat *seat);
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_pointer_resource_create(Ecore_Wl2_Pointer *ptr, struct wl_client *client, const struct wl_pointer_interface *implementation, int version, uint32_t id);
+/**
+ * Set the actions which are supported by you
+ *
+ * @param offer Offer object to use
+ * @param actions A or´ed value of mutliple Ecore_Wl2_Drag_Action values
+ * @param action the preffered action out of the actions
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI void ecore_wl2_offer_actions_set(Ecore_Wl2_Offer *offer, Ecore_Wl2_Drag_Action actions, Ecore_Wl2_Drag_Action action);
 
-/** @since 1.17 */
-EAPI Ecore_Wl2_Keyboard *ecore_wl2_keyboard_get(Ecore_Wl2_Seat *seat);
-/** @since 1.17 */
-EAPI Eina_Bool ecore_wl2_keyboard_resource_create(Ecore_Wl2_Keyboard *kbd, struct wl_client *client, const struct wl_keyboard_interface *implementation, int version, uint32_t id);
-/** @since 1.17 */
-EAPI void ecore_wl2_keyboard_repeat_info_set(Ecore_Wl2_Keyboard *kbd, double rate, double delay);
+/**
+ * Get action which is set by either the data source or in the last call of actions_set
+ *
+ * @param offer Offer object to use
+ *
+ * @return the prefered action
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI Ecore_Wl2_Drag_Action ecore_wl2_offer_action_get(Ecore_Wl2_Offer *offer);
 
-/** @since 1.17 */
-EAPI Ecore_Wl2_Display *ecore_wl2_window_display_get(const Ecore_Wl2_Window *window);
+/**
+ * Get the mime types which are given by the source
+ *
+ * @param offer the offer to query
+ *
+ * @return a eina array of strdup´ed strings, this array must NOT be changed or freed
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ */
+EAPI Eina_Array* ecore_wl2_offer_mimes_get(Ecore_Wl2_Offer *offer);
 
-/* # ifdef __cplusplus */
-/* } */
-/* # endif */
+/**
+ * Set mimetypes you are accepting under this offer
+ *
+ * @param offer the offer to use
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI void ecore_wl2_offer_mimes_set(Ecore_Wl2_Offer *offer, Eina_Array *mimes);
+
+/**
+ * Accept a single mime type for an offer
+ *
+ * @param offer the offer to use
+ * @param mime_type the mime type
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_offer_accept(Ecore_Wl2_Offer *offer, const char *mime_type);
+
+/**
+ * Request the data from this offer.
+ * The event ECORE_WL2_EVENT_OFFER_DATA_READY is called when the data is available.
+ * There offer will be not destroyed as long as requested data is not emitted by the event.
+ *
+ * @param offer the offer to use
+ * @param mime the mimetype to receive
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI void ecore_wl2_offer_receive(Ecore_Wl2_Offer *offer, char *mime);
+
+/**
+ * Request the data from this offer on an externally managed fd.
+ * The event ECORE_WL2_EVENT_OFFER_DATA_READY is called when the data is available.
+ * There offer will be not destroyed as long as requested data is not emitted by the event.
+ *
+ * @param offer the offer to use
+ * @param mime the mimetype to receive
+ * @param fd the fd to pass for receiving
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_offer_proxy_receive(Ecore_Wl2_Offer *offer, const char *mime, int fd);
+
+/**
+ * End the use of a proxy received offer. This may invalidate the offer object
+ *
+ * @param offer the offer
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.20
+ */
+EAPI void ecore_wl2_offer_proxy_receive_end(Ecore_Wl2_Offer *offer);
+
+/**
+ * Check if the given offer supports the given mimetype
+ *
+ * @param offer the offer to use
+ * @param mime the mimetype to check
+ *
+ * @return Returns true if the mimetype is supported by this offer, false if not
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI Eina_Bool ecore_wl2_offer_supports_mime(Ecore_Wl2_Offer *offer, const char *mime);
+
+/**
+ * Mark this offer as finished
+ * This will call the dnd_finished event on the source of the sender.
+ *
+ * @param offer the offer to use
+ *
+ * @ingroup Ecore_Wl2_Dnd_Group
+ * @since 1.19
+ */
+EAPI void ecore_wl2_offer_finish(Ecore_Wl2_Offer *offer);
+
+/**
+ * Disable session recovery for any further connections.  Must be called
+ * before connecting.  This is irreversible and not intended for general
+ * use.
+ *
+ * @since 1.19
+ */
+EAPI void ecore_wl2_session_recovery_disable(void);
 
 # endif
 
 # undef EAPI
 # define EAPI
 
+/* # ifdef __cplusplus */
+/* } */
+/* # endif */
+
 #endif
