@@ -13,9 +13,12 @@ typedef Eo Elm_Atspi_App_Object;
 
 
 #endif
+/** AT-SPI application object class
+ *
+ * @ingroup Elm_Atspi_App_Object
+ */
 #define ELM_ATSPI_APP_OBJECT_CLASS elm_atspi_app_object_class_get()
 
-EWAPI const Eo_Class *elm_atspi_app_object_class_get(void);
-
+EWAPI const Efl_Class *elm_atspi_app_object_class_get(void);
 
 #endif
