@@ -15,7 +15,7 @@ typedef Eo Elm_List;
  * @brief Set list's resizing behavior, transverse axis scrolling and items
  * cropping. See each mode's description for more details.
  *
- * @note Default value is @ref Elm_List_Mode.ELM_LIST_SCROLL.
+ * @note Default value is @ref ELM_LIST_SCROLL.
  *
  * Values here don't work as bitmasks -- only one can be chosen at a time.
  *
@@ -25,38 +25,42 @@ typedef Eo Elm_List;
  */
 typedef enum
 {
-  ELM_LIST_COMPRESS = 0, /** The list won't set any of its size hints to inform
+  ELM_LIST_COMPRESS = 0, /**< The list won't set any of its size hints to inform
                           * how a possible container should resize it. Then, if
                           * it's not created as a "resize object", it might end
                           * with zeroed dimensions. The list will respect the
                           * container's geometry and, if any of its items won't
                           * fit into its transverse axis, one won't be able to
                           * scroll it in that direction. */
-  ELM_LIST_SCROLL, /** Default value. This is the same as #ELM_LIST_COMPRESS,
+  ELM_LIST_SCROLL, /**< Default value. This is the same as #ELM_LIST_COMPRESS,
                     * with the exception that if any of its items won't fit
                     * into its transverse axis, one will be able to scroll it
                     * in that direction. */
-  ELM_LIST_LIMIT, /** Sets a minimum size hint on the list object, so that
+  ELM_LIST_LIMIT, /**< Sets a minimum size hint on the list object, so that
                    * containers may respect it (and resize itself to fit the
                    * child properly). More specifically, a minimum size hint
                    * will be set for its transverse axis, so that the largest
                    * item in that direction fits well. This is naturally bound
                    * by the list object's maximum size hints, set externally.
                    */
-  ELM_LIST_EXPAND, /** Besides setting a minimum size on the transverse axis,
-                    * just like on @ref Elm_List_Mode.ELM_LIST_LIMIT, the list
-                    * will set a minimum size on th longitudinal axis, trying
-                    * to reserve space to all its children to be visible at a
-                    * time. . This is naturally bound by the list object's
-                    * maximum size hints, set externally. */
-  ELM_LIST_LAST /** Indicates error if returned by elm_list_mode_get(). */
+  ELM_LIST_EXPAND, /**< Besides setting a minimum size on the transverse axis,
+                    * just like on @ref ELM_LIST_LIMIT, the list will set a
+                    * minimum size on the longitudinal axis, trying to reserve
+                    * space to all its children to be visible at a time. . This
+                    * is naturally bound by the list object's maximum size
+                    * hints, set externally. */
+  ELM_LIST_LAST /**< Indicates error if returned by elm_list_mode_get(). */
 } Elm_List_Mode;
 
 
 #endif
+/** Elementary list class
+ *
+ * @ingroup Elm_List
+ */
 #define ELM_LIST_CLASS elm_list_class_get()
 
-EWAPI const Eo_Class *elm_list_class_get(void);
+EWAPI const Efl_Class *elm_list_class_get(void);
 
 /**
  * @brief Control horizontal mode on the list object.
@@ -135,7 +139,8 @@ EOAPI Elm_Object_Select_Mode elm_obj_list_select_mode_get(const Eo *obj);
  * an item or selecting it with a key movement. Clicking on a focusable widget
  * inside an item will couse this particular item to get focus as usual.
  *
- * @param[in] enabled The tree effect status (true = enabled, false = disabled)
+ * @param[in] enabled The tree effect status ($true = enabled, @c false =
+ * disabled)
  *
  * @ingroup Elm_List
  */
@@ -150,7 +155,7 @@ EOAPI void elm_obj_list_focus_on_selection_set(Eo *obj, Eina_Bool enabled);
  * an item or selecting it with a key movement. Clicking on a focusable widget
  * inside an item will couse this particular item to get focus as usual.
  *
- * @return The tree effect status (true = enabled, false = disabled)
+ * @return The tree effect status ($true = enabled, @c false = disabled)
  *
  * @ingroup Elm_List
  */
@@ -428,7 +433,7 @@ EOAPI Elm_Widget_Item *elm_obj_list_item_insert_after(Eo *obj, Elm_Widget_Item *
  *
  * @ingroup Elm_List
  */
-EOAPI Elm_Widget_Item *elm_obj_list_at_xy_item_get(const Eo *obj, Evas_Coord x, Evas_Coord y, int *posret);
+EOAPI Elm_Widget_Item *elm_obj_list_at_xy_item_get(const Eo *obj, int x, int y, int *posret);
 
 /**
  * @brief Append a new item to the list object.
@@ -552,76 +557,99 @@ EOAPI void elm_obj_list_clear(Eo *obj);
  */
 EOAPI Elm_Widget_Item *elm_obj_list_item_sorted_insert(Eo *obj, const char *label, Efl_Canvas_Object *icon, Efl_Canvas_Object *end, Evas_Smart_Cb func, const void *data, Eina_Compare_Cb cmp_func);
 
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_ACTIVATED;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_EDGE_TOP;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_EDGE_BOTTOM;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_EDGE_LEFT;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_EDGE_RIGHT;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_SWIPE;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_HIGHLIGHTED;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_UNHIGHLIGHTED;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_ITEM_FOCUSED;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_ITEM_UNFOCUSED;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_ITEM_REORDER_ANIM_START;
-EOAPI extern const Eo_Event_Description _ELM_LIST_EVENT_ITEM_REORDER_ANIM_STOP;
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_ACTIVATED;
 
-/**
- * No description
+/** Called when activated
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_ACTIVATED (&(_ELM_LIST_EVENT_ACTIVATED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_EDGE_TOP;
+
+/** Called when top edge was reached
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_EDGE_TOP (&(_ELM_LIST_EVENT_EDGE_TOP))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_EDGE_BOTTOM;
+
+/** Called when bottom edge was reached
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_EDGE_BOTTOM (&(_ELM_LIST_EVENT_EDGE_BOTTOM))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_EDGE_LEFT;
+
+/** Called when left edge was reached
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_EDGE_LEFT (&(_ELM_LIST_EVENT_EDGE_LEFT))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_EDGE_RIGHT;
+
+/** Called when right edge was reached
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_EDGE_RIGHT (&(_ELM_LIST_EVENT_EDGE_RIGHT))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_SWIPE;
+
+/** Called when swipe is detected
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_SWIPE (&(_ELM_LIST_EVENT_SWIPE))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_HIGHLIGHTED;
+
+/** Called when highlighted
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_HIGHLIGHTED (&(_ELM_LIST_EVENT_HIGHLIGHTED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_UNHIGHLIGHTED;
+
+/** Called when no longer highlighted
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_UNHIGHLIGHTED (&(_ELM_LIST_EVENT_UNHIGHLIGHTED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_ITEM_FOCUSED;
+
+/** Called when item got focus
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_ITEM_FOCUSED (&(_ELM_LIST_EVENT_ITEM_FOCUSED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_ITEM_UNFOCUSED;
+
+/** Called when item no longer has focus
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_ITEM_UNFOCUSED (&(_ELM_LIST_EVENT_ITEM_UNFOCUSED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_ITEM_REORDER_ANIM_START;
+
+/** Called when item reorder animation started
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_ITEM_REORDER_ANIM_START (&(_ELM_LIST_EVENT_ITEM_REORDER_ANIM_START))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_LIST_EVENT_ITEM_REORDER_ANIM_STOP;
+
+/** Called when item reorder animation stopped
+ *
+ * @ingroup Elm_List
  */
 #define ELM_LIST_EVENT_ITEM_REORDER_ANIM_STOP (&(_ELM_LIST_EVENT_ITEM_REORDER_ANIM_STOP))
 
